@@ -66,7 +66,7 @@ def build_model(model_name):
 
 	return model_obj[model_name]
 
-def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True):
+def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base'):
 
 	"""
 	This function verifies an image pair is same person or different persons.
@@ -161,12 +161,16 @@ def verify(img1_path, img2_path = '', model_name = 'VGG-Face', distance_metric =
 				img1_representation = represent(img_path = img1_path
 						, model_name = model_name, model = custom_model
 						, enforce_detection = enforce_detection, detector_backend = detector_backend
-						, align = align)
+						, align = align
+						, normalization = normalization
+						)
 
 				img2_representation = represent(img_path = img2_path
 						, model_name = model_name, model = custom_model
 						, enforce_detection = enforce_detection, detector_backend = detector_backend
-						, align = align)
+						, align = align
+						, normalization = normalization
+						)
 
 				#----------------------
 				#find distances between embeddings
@@ -458,7 +462,7 @@ def analyze(img_path, actions = ['emotion', 'age', 'gender', 'race'] , models =
 
 		return resp_obj
 
-def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True):
+def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, prog_bar = True, normalization = 'base'):
 
 	"""
 	This function applies verification several times and find an identity in a database
@@ -571,7 +575,9 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 					representation = represent(img_path = employee
 						, model_name = model_name, model = custom_model
 						, enforce_detection = enforce_detection, detector_backend = detector_backend
-						, align = align)
+						, align = align
+						, normalization = normalization
+						)
 
 					instance.append(representation)
 
@@ -613,7 +619,9 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 				target_representation = represent(img_path = img_path
 					, model_name = model_name, model = custom_model
 					, enforce_detection = enforce_detection, detector_backend = detector_backend
-					, align = align)
+					, align = align
+					, normalization = normalization
+					)
 
 				for k in metric_names:
 					distances = []
@@ -704,7 +712,7 @@ def find(img_path, db_path, model_name ='VGG-Face', distance_metric = 'cosine',
 
 	return None
 
-def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection = True, detector_backend = 'opencv', align = True):
+def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection = True, detector_backend = 'opencv', align = True, normalization = 'base'):
 
 	"""
 	This function represents facial images as vectors.
@@ -722,6 +730,8 @@ def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection
 
 		detector_backend (string): set face detector backend as retinaface, mtcnn, opencv, ssd or dlib
 
+		normalization (string): normalize the input image before feeding to model
+
 	Returns:
 		Represent function returns a multidimensional vector. The number of dimensions is changing based on the reference model. E.g. FaceNet returns 128 dimensional vector; VGG-Face returns 2622 dimensional vector.
 	"""
@@ -732,7 +742,7 @@ def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection
 	#---------------------------------
 
 	#decide input shape
-	input_shape =  input_shape_x, input_shape_y= functions.find_input_shape(model)
+	input_shape_x, input_shape_y = functions.find_input_shape(model)
 
 	#detect and align
 	img = functions.preprocess_face(img = img_path
@@ -741,12 +751,19 @@ def represent(img_path, model_name = 'VGG-Face', model = None, enforce_detection
 		, detector_backend = detector_backend
 		, align = align)
 
+	#---------------------------------
+	#custom normalization
+
+	img = functions.normalize_input(img = img, normalization = normalization)
+
+	#---------------------------------
+
 	#represent
 	embedding = model.predict(img)[0].tolist()
 
 	return embedding
 
-def stream(db_path = '', model_name ='VGG-Face', distance_metric = 'cosine', enable_face_analysis = True, source = 0, time_threshold = 5, frame_threshold = 5):
+def stream(db_path = '', model_name ='VGG-Face', detector_backend = 'opencv', distance_metric = 'cosine', enable_face_analysis = True, source = 0, time_threshold = 5, frame_threshold = 5):
 
 	"""
 	This function applies real time face recognition and facial attribute analysis
@@ -756,6 +773,8 @@ def stream(db_path = '', model_name ='VGG-Face', distance_metric = 'cosine', ena
 
 		model_name (string): VGG-Face, Facenet, OpenFace, DeepFace, DeepID, Dlib or Ensemble
 
+		detector_backend (string): opencv, ssd, mtcnn, dlib, retinaface
+
 		distance_metric (string): cosine, euclidean, euclidean_l2
 
 		enable_facial_analysis (boolean): Set this to False to just run face recognition
@@ -774,10 +793,10 @@ def stream(db_path = '', model_name ='VGG-Face', distance_metric = 'cosine', ena
 	if frame_threshold < 1:
 		raise ValueError("frame_threshold must be greater than the value 1 but you passed "+str(frame_threshold))
 
-	realtime.analysis(db_path, model_name, distance_metric, enable_face_analysis
+	realtime.analysis(db_path, model_name, detector_backend, distance_metric, enable_face_analysis
 						, source = source, time_threshold = time_threshold, frame_threshold = frame_threshold)
 
-def detectFace(img_path, detector_backend = 'opencv', enforce_detection = True):
+def detectFace(img_path, detector_backend = 'opencv', enforce_detection = True, align = True):
 
 	"""
 	This function applies pre-processing stages of a face recognition pipeline including detection and alignment
@@ -792,7 +811,7 @@ def detectFace(img_path, detector_backend = 'opencv', enforce_detection = True):
 	"""
 
 	img = functions.preprocess_face(img = img_path, detector_backend = detector_backend
-		, enforce_detection = enforce_detection)[0] #preprocess_face returns (1, 224, 224, 3)
+		, enforce_detection = enforce_detection, align = align)[0] #preprocess_face returns (1, 224, 224, 3)
 	return img[:, :, ::-1] #bgr to rgb
 
 #---------------------------
