@@ -8,14 +8,16 @@ from pathlib import Path
 from deepface.detectors import FaceDetector
 
 import tensorflow as tf
-tf_version = int(tf.__version__.split(".")[0])
+tf_version = tf.__version__
+tf_major_version = int(tf_version.split(".")[0])
+tf_minor_version = int(tf_version.split(".")[1])
 
-if tf_version == 1:
+if tf_major_version == 1:
 	import keras
 	from keras.preprocessing.image import load_img, save_img, img_to_array
 	from keras.applications.imagenet_utils import preprocess_input
 	from keras.preprocessing import image
-elif tf_version == 2:
+elif tf_major_version == 2:
 	from tensorflow import keras
 	from tensorflow.keras.preprocessing.image import load_img, save_img, img_to_array
 	from tensorflow.keras.applications.imagenet_utils import preprocess_input
@@ -102,6 +104,57 @@ def detect_face(img, detector_backend = 'opencv', grayscale = False, enforce_det
 			else:
 			  raise ValueError("Face could not be detected. Please confirm that the picture is a face photo or consider to set enforce_detection param to False.")
 
+def normalize_input(img, normalization = 'base'):
+
+	#issue 131 declares that some normalization techniques improves the accuracy
+
+	if normalization == 'base':
+		return img
+	else: #@trevorgribble recommend the following idea
+		
+		img *= 255 #restore input in scale of [0, 255] because it was normalized in scale of  [0, 1] in preprocess_face
+
+		if normalization == 'Facenet':
+			mean, std = img.mean(), img.std()
+			img = (img - mean) / std
+
+		elif normalization == 'v1':
+			#BGR mean subtraction / 255 normalization
+			img[..., 0]-= 131.0912
+			img[..., 1] -= 103.8827
+			img[..., 2] -= 91.4953
+			img = img[..., ::-1]
+			img /= 255
+
+		elif(normalization =="v2"):
+			#RGB mean subtraction / 255 normalization
+			img[..., 0]-= 131.0912
+			img[..., 1] -= 103.8827
+			img[..., 2] -= 91.4953
+			img /= 255
+
+		elif(normalization =="v3"):
+			#BGR mean subtraction normalization
+			img[..., 0]-= 131.0912
+			img[..., 1] -= 103.8827
+			img[..., 2] -= 91.4953
+			img = img[..., ::-1]
+
+		elif(normalization =="v4"):
+			#RGB mean subtraction normalization
+			img[..., 0]-= 131.0912
+			img[..., 1] -= 103.8827
+			img[..., 2] -= 91.4953
+
+		elif(normalization=="v6"):
+			# simply / 127.5 - 1 (similar to facenet 2018 model preprocessing step as @iamrishab posted)
+			img /= 127.5
+			img -= 1
+
+	#-----------------------------
+
+	return img
+
 def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_detection = True, detector_backend = 'opencv', return_region = False, align = True):
 
 	#img might be path, base64 or numpy array. Convert it to numpy whatever it is.
@@ -123,19 +176,16 @@ def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_dete
 	#post-processing
 	if grayscale == True:
 		img = cv2.cvtColor(img, cv2.COLOR_BGR2GRAY)
-	
+
 	#---------------------------------------------------
 	#resize image to expected shape
 
 	# img = cv2.resize(img, target_size) #resize causes transformation on base image, adding black pixels to resize will not deform the base image
-	
-	# First resize the longer side to the target size
-	#factor = target_size[0] / max(img.shape)
-	
+
 	factor_0 = target_size[0] / img.shape[0]
 	factor_1 = target_size[1] / img.shape[1]
 	factor = min(factor_0, factor_1)
-	
+
 	dsize = (int(img.shape[1] * factor), int(img.shape[0] * factor))
 	img = cv2.resize(img, dsize)
 
@@ -147,17 +197,21 @@ def preprocess_face(img, target_size=(224, 224), grayscale = False, enforce_dete
 		img = np.pad(img, ((diff_0 // 2, diff_0 - diff_0 // 2), (diff_1 // 2, diff_1 - diff_1 // 2), (0, 0)), 'constant')
 	else:
 		img = np.pad(img, ((diff_0 // 2, diff_0 - diff_0 // 2), (diff_1 // 2, diff_1 - diff_1 // 2)), 'constant')
-	
+
 	#double check: if target image is not still the same size with target.
 	if img.shape[0:2] != target_size:
 		img = cv2.resize(img, target_size)
-	
+
 	#---------------------------------------------------
-	
-	img_pixels = image.img_to_array(img)
+
+	#normalizing the image pixels
+
+	img_pixels = image.img_to_array(img) #what this line doing? must?
 	img_pixels = np.expand_dims(img_pixels, axis = 0)
 	img_pixels /= 255 #normalize input in [0, 1]
 
+	#---------------------------------------------------
+
 	if return_region == True:
 		return img_pixels, region
 	else:
@@ -175,6 +229,16 @@ def find_input_shape(model):
 	else:
 		input_shape = input_shape[1:3]
 
+	#----------------------
+	#issue 289: it seems that tf 2.5 expects you to resize images with (x, y)
+	#whereas its older versions expect (y, x)
+
+	if tf_major_version == 2 and tf_minor_version >= 5:
+		x = input_shape[0]; y = input_shape[1]
+		input_shape = (y, x)
+
+	#----------------------
+
 	if type(input_shape) == list: #issue 197: some people got array here instead of tuple
 		input_shape = tuple(input_shape)
 
